#!/usr/bin/env python
# coding=utf-8
"""
@author: Jiawei Wu
@create time: 2020-03-18 11:52
@edit time: 2020-03-30 10:12
@file: /RL4Net-lib/wjwgym-home/wjwgym/__version__.py
"""



VERSION = (0, 1, 6)

__version__ = '.'.join(map(str, VERSION))
